@@ -4,7 +4,7 @@
 #> open https://flavjack.github.io/inti/
 #> open https://flavjack.shinyapps.io/tarpuy/
 #> author .: Flavio Lozano-Isla (lozanoisla.com)
-#> date .: 2020-03-19
+#> date .: 2020-03-24
 # -------------------------------------------------------------------------
 
 # -------------------------------------------------------------------------
@@ -19,5 +19,7 @@ library(metathis)
 library(googlesheets4)
 library(googleAuthR)
 library(shinydashboard)
+library(tidyverse)
+library(stringi)
 
 })
